diff --git a/Frontend/src/app/components/mdx.tsx b/Frontend/src/app/components/mdx.tsx
index 4e814a1..457a856 100644
--- a/Frontend/src/app/components/mdx.tsx
+++ b/Frontend/src/app/components/mdx.tsx
@@ -16,22 +16,34 @@ import {
*/
const components: any = {
h1: ({ children }: { children: ReactNode }): ReactElement => (
- {children}
+
+ {children}
+
),
h2: ({ children }: { children: ReactNode }): ReactElement => (
- {children}
+
+ {children}
+
),
h3: ({ children }: { children: ReactNode }): ReactElement => (
- {children}
+
+ {children}
+
),
h4: ({ children }: { children: ReactNode }): ReactElement => (
- {children}
+
+ {children}
+
),
h5: ({ children }: { children: ReactNode }): ReactElement => (
- {children}
+
+ {children}
+
),
h6: ({ children }: { children: ReactNode }): ReactElement => (
- {children}
+
+ {children}
+
),
a: ({
href,
@@ -97,16 +109,21 @@ export const CustomMDX = (props: any): ReactElement => (
/**
* A heading component.
*
* @param size the size of the heading.
* @param children the children within the heading
* @return the heading jsx
*/
const Heading = ({
+ className,
size,
children,
}: {
- size: string;
+ className: string;
+ size: number;
children: ReactNode;
}): ReactElement => (
-
{children}
+ = 2 && "pt-7", className)}>
+ {children}
+
);
@@ -97,16 +109,21 @@ export const CustomMDX = (props: any): ReactElement => (
* A heading component.
*
- * @param size the size of the heading.
+ * @param className the class name of the heading
+ * @param size the size of the heading
* @param children the children within the heading
* @return the heading jsx